# users generic .bashrc file for bash(1)
#
# Copyright (c) 2006 Daichi GOTO <daichi@ongs.co.jp>
# Copyright (c) 2006 ONGS Inc. <info@ongs.co.jp>
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
# THE POSSIBILITY OF SUCH DAMAGE.

# author: Daichi GOTO (daichi@ongs.co.jp)
# first edition: Fri Apr  7 20:04:55 2006
# last modified: $Date: 2007/07/09 05:56:41 $
# version: $Revision: 1.21 $


## Environment variable configuration
#
# LANG
#
export LANG=ja_JP.UTF-8


## Default shell configuration
#
# set prompt
#
case ${UID} in
0)
    PS1='\[\033[1;31m\]${PWD}\$\[\033[0m\] '
    PS2='\[\033[1;31m\]>\[\033[0m\] '
    [ -n "${REMOTEHOST}${SSH_CONNECTION}" ] && 
        PS1='\[\033[1;36m\]'"$(echo ${HOSTNAME%%.*} | tr '[a-z]' '[A-Z]') ${PS1}"
    ;;
*)
    PS1='\[\033[31m\]${PWD}\$\[\033[0m\] '
    PS2='\[\033[31m\]>\[\033[0m\] '
    [ -n "${REMOTEHOST}${SSH_CONNECTION}" ] && 
        PS1='\[\033[36m\]'"$(echo ${HOSTNAME%%.*} | tr '[a-z]' '[A-Z]') ${PS1}"
    ;;
esac


## Completion configuration
#
complete -A directory cd
complete -A command which where man jman
complete -A alias alias unalias
complete -A variable printenv
case ${UID} in
0)
    [ -f /usr/local/share/examples/pkgtools/bash/complete.sample ] &&
        . /usr/local/share/examples/pkgtools/bash/complete.sample
    ;;
esac


## Alias configuration
#
alias where="command -v"
alias j="jobs -l"

case "${OSTYPE}" in
freebsd*|darwin*)
    alias ls="ls -G -w"
    ;;
linux*)
    alias ls="ls --color"
    ;;
esac

alias la="ls -a"
alias lf="ls -F"
alias ll="ls -l"

alias du="du -h"
alias df="df -h"

alias su="su -l"

case ${UID} in
0)
    alias checkports='portversion -v -l \<'
    alias updateports='portsnap fetch extract update && (cd /usr/ports/; make index) && checkports'
    alias appsupgrade='pkgdb -F && BATCH=yes NO_CHECKSUM=yes portupgrade -a'
    #alias portsclean portsclean -CDP
    ;;
esac


## terminal configuration
#
unset LSCOLORS
case "${TERM}" in
xterm)
    export TERM=xterm-color
    ;;
kterm)
    export TERM=kterm-color
    # set BackSpace control character
    stty erase
    ;;
cons25)
    unset LANG
    export LSCOLORS=ExFxCxdxBxegedabagacad
    export LS_COLORS='di=01;34:ln=01;35:so=01;32:ex=01;31:bd=46;34:cd=43;34:su=41;30:sg=46;30:tw=42;30:ow=43;30'
    ;;
esac

# set terminal title including current directory
#
case "${TERM}" in
kterm*|xterm*)
    PROMPT_COMMAND='echo -e "\033]0;'"${USER}@${HOSTNAME%%.*}:"'${PWD}\007\c"'
    export LSCOLORS=exfxcxdxbxegedabagacad
    export LS_COLORS='di=34:ln=35:so=32:pi=33:ex=31:bd=46;34:cd=43;34:su=41;30:sg=46;30:tw=42;30:ow=43;30'
    ;;
esac


## load user .bashrc configuration file
#
[ -f ~/.bashrc.mine ] && . ~/.bashrc.mine
